summaryrefslogtreecommitdiffstats
path: root/src/kchmsetupdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kchmsetupdialog.cpp')
-rw-r--r--src/kchmsetupdialog.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/kchmsetupdialog.cpp b/src/kchmsetupdialog.cpp
index 00e0502..55b643e 100644
--- a/src/kchmsetupdialog.cpp
+++ b/src/kchmsetupdialog.cpp
@@ -25,14 +25,14 @@
#include <tqwhatsthis.h>
/*
* Constructs a KCHMSetupDialog as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-KCHMSetupDialog::KCHMSetupDialog( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
- : TQDialog( tqparent, name, modal, fl )
+KCHMSetupDialog::KCHMSetupDialog( TQWidget* parent, const char* name, bool modal, WFlags fl )
+ : TQDialog( parent, name, modal, fl )
{
if ( !name )
setName( "MyDialog1" );
@@ -25,14 +25,14 @@
#include <tqwhatsthis.h>
/*
- * Constructs a KCHMSetupDialog as a child of 'tqparent', with the
+ * Constructs a KCHMSetupDialog as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*